import type { Balances, Chain, ChainsConfig, Network, SignedTx, StaticPlatformMethods, TokenId, TxHash } from "@wormhole-foundation/sdk-connect";
import { PlatformContext } from "@wormhole-foundation/sdk-connect";
import { AptosClient } from "aptos";
import { AptosChain } from "./chain.js";
import type { AptosChains, AptosPlatformType } from "./types.js";
import type { AnyAptosAddress } from "./types.js";
/**
 * @category Aptos
 */
export declare class AptosPlatform<N extends Network> extends PlatformContext<N, AptosPlatformType> implements StaticPlatformMethods<AptosPlatformType, typeof AptosPlatform> {
    static _platform: "Aptos";
    constructor(network: N, config?: ChainsConfig<N, AptosPlatformType>);
    getRpc<C extends AptosChains>(chain: C): AptosClient;
    getChain<C extends AptosChains>(chain: C, rpc?: AptosClient): AptosChain<N, C>;
    static nativeTokenId<N extends Network, C extends AptosChains>(network: N, chain: C): TokenId<C>;
    static isNativeTokenId<N extends Network, C extends AptosChains>(network: N, chain: C, tokenId: TokenId): boolean;
    static isSupportedChain(chain: Chain): boolean;
    static getDecimals(chain: Chain, rpc: AptosClient, token: AnyAptosAddress): Promise<number>;
    static getBalance(chain: Chain, rpc: AptosClient, walletAddress: string, token: AnyAptosAddress): Promise<bigint | null>;
    static getBalances(chain: Chain, rpc: AptosClient, walletAddress: string, tokens: AnyAptosAddress[]): Promise<Balances>;
    static sendWait(chain: Chain, rpc: AptosClient, stxns: SignedTx[]): Promise<TxHash[]>;
    static getLatestBlock(rpc: AptosClient): Promise<number>;
    static getLatestFinalizedBlock(rpc: AptosClient): Promise<number>;
    static chainFromChainId(chainId: string | bigint): [Network, AptosChains];
    static chainFromRpc(rpc: AptosClient): Promise<[Network, AptosChains]>;
}
//# sourceMappingURL=platform.d.ts.map